<template>
  <div class="main">
    <div class="main_header">
      <div class="header_item">
        <span class="header_label">时间范围：</span>
        <el-date-picker
          v-model="dataTime"
          type="daterange"
          range-separator="至"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
          value-format="yyyy-MM-dd">
        </el-date-picker>
      </div>
      <div class="header_item">
        <el-button icon="el-icon-search" @click="searchSmokeList(true)">查询</el-button>
        <!-- <el-button icon="el-icon-search" v-if="showButton('search')">查询</el-button> -->
      </div>
    </div>
    <div class="main_content">
      <el-table
        v-loading="loading"
        :data="smokeList"
        height="100%">
        <el-table-column label="序号" align="center" >
          <template #default="scope">
            <div>
              <span>{{(pageNum - 1) * pageSize + scope.$index + 1}}</span>
            </div>
          </template>
        </el-table-column>
        <el-table-column prop="bigDeviceName" label="采集时间" align="center" ></el-table-column>
        <el-table-column prop="bigNumber" label="设备" align="center"></el-table-column>
        <el-table-column prop="dc" label="粉尘浓度(mg/m³)" align="center" ></el-table-column>
        <el-table-column prop="t" label="温度(℃)" align="center" ></el-table-column>
        <el-table-column prop="dp" label="压差(pa)" align="center" ></el-table-column>
        <el-table-column prop="oc" label="氧气浓度(%)" align="center" ></el-table-column>
        <el-table-column prop="fans" label="风速(m/s)" align="center" ></el-table-column>
        <el-table-column prop="alarm" label="设备报警" align="center" ></el-table-column>
        <el-table-column label="风机启动" align="center" >
          <template #default="{ row }">
            <div>
              {{row.fanrun ? row.fanrun == 1 ? '运行' : '未运行' : ''}}
            </div>
          </template>
        </el-table-column>
      </el-table>
    </div>
    <div class="main_footer">

    </div>
  </div>
</template>

<script>
import { buttonPinia } from '../../pinia';
export default {
  data() {
    return {
      dataTime: '',
      pageNum: 1,
      pageSize: 10,
      total: 0,
      loading: false,
      smokeList: []
    }
  },
  mounted() {
    this.searchSmokeList(true);
  },
  methods: {
    // 查询焊接烟尘信息
    searchSmokeList(bol) {
      if(bol) {
        this.pageNum = 1;
      }
      this.loading = true;
      this.smokeList = [];
      this.$api.Green.searchSmokeList({
        strTime: this.dataTime ? this.dataTime[0] : '',
        endTime: this.dataTime ? this.dataTime[1] : '',
        pageNum: this.pageNum,
        pageSize: this.pageSize
      }).then(res => {
        if(res.success) {
          this.total = res.data.total;
          this.smokeList = res.data.list;
        }
        this.loading = false;
      }).catch(() => {
        this.loading = false;
      })
    },
    // 判断按钮权限信息
    showButton(str) {
      const pinia = buttonPinia();
      return pinia.$state.buttonInfo.includes(str);
    }
  }
};
</script>

<style lang="scss" scoped>
@import '@/style/layout-main.scss';
</style>